@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Log::Any '$log';
 
-our $VERSION = '0.15'; # VERSION
+our $VERSION = '0.16'; # VERSION
 
 use Data::Clean::FromJSON;
 use Data::Clean::JSON;
@@ -56,7 +56,7 @@ has _pa                    => (             # Perinci::Access object
             handlers => {
                 pl => Perinci::Access::Perl->new(
                     load => 0,
-                    extra_wrapper_convert => {
+                    set_function_properties => {
                         #timeout => 300,
                     },
                     #use_tx            => $self->{use_tx},
@@ -64,7 +64,7 @@ has _pa                    => (             # Perinci::Access object
                 ),
                 '' => Perinci::Access::Schemeless->new(
                     load => 0,
-                    extra_wrapper_convert => {
+                    set_function_properties => {
                         #timeout => 300,
                     },
                     #use_tx            => $self->{use_tx},
@@ -499,7 +499,7 @@ Perinci::Access::Simple::Server::Socket - Implement Riap::Simple server over soc
 
 =head1 VERSION
 
-version 0.15
+This document describes version 0.16 of Perinci::Access::Simple::Server::Socket (from Perl distribution Perinci-Access-Simple-Server), released on 2014-04-30.
 
 =head1 SYNOPSIS
 
@@ -528,11 +528,6 @@ This module uses L<Log::Any> for logging.
 
 This module uses L<Moo> for object system.
 
-=head1 FUNCTIONS
-
-
-None are exported by default, but they are exportable.
-
 =head1 ATTRIBUTES
 
 =head2 name => STR (default is basename of $0)
@@ -679,7 +674,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
